@@ -3,11 +3,11 @@ import socket
 from datetime import datetime, timedelta
 from ipaddress import ip_address
 from pathlib import Path
+import warnings
 
 from cryptography.hazmat.primitives import hashes, serialization
 from cryptography.hazmat.primitives.asymmetric import rsa
 from cryptography.x509 import (BasicConstraints, CertificateBuilder, DNSName,
-                               ExtendedKeyUsage, ExtendedKeyUsageOID,
                                IPAddress, Name, NameAttribute,
                                SubjectAlternativeName, random_serial_number)
 from cryptography.x509.oid import NameOID
@@ -15,7 +15,7 @@ from cryptography.x509.oid import NameOID
 log = logging.getLogger(__name__)
 
 
-def generate_certs(path, days=3652, key_size=2048, separate_key=False):
+def _generate_certs(path, days=3652, key_size=2048, separate_key=False):
     # DO NOT USE THIS FOR ANYTHING PRODUCTION RELATED, EVER!
     # Generate private key
     # 2048 is the minimum that works as of 3.9
@@ -43,6 +43,9 @@ def generate_certs(path, days=3652, key_size=2048, separate_key=False):
         IPAddress(ip_address("::1")),
         IPAddress(ip_address(ip)),
     ]
+    # Set it so the certificate can be a root certificate with
+    # ca=true, path_length=0 means it can only sign itself.
+    constraints = BasicConstraints(ca=True, path_length=0)
 
     cert = (CertificateBuilder()
             .issuer_name(subject)
@@ -52,13 +55,18 @@ def generate_certs(path, days=3652, key_size=2048, separate_key=False):
             .not_valid_after(datetime.utcnow() + timedelta(days=days))
             .add_extension(SubjectAlternativeName(alt_names), critical=False)
             .public_key(key.public_key())
-            .add_extension(BasicConstraints(ca=False, path_length=None),
-                           critical=True)
-            .add_extension(ExtendedKeyUsage([ExtendedKeyUsageOID.CLIENT_AUTH]),
-                           critical=True)
+            .add_extension(constraints, critical=False)
             .sign(private_key=key, algorithm=hashes.SHA256()))
 
     cert_path = Path(path).joinpath("cert.pem")
     with open(cert_path, "ab") as f:
         f.write(cert.public_bytes(serialization.Encoding.PEM))
     log.debug("Certificate generated")
+
+
+def generate_certs(path, days=3652, key_size=2048, separate_key=False):
+    _message = ("_generate_certs will be removed from the public API as of ",
+                "version 0.4.")
+    warnings.warn(_message, PendingDeprecationWarning)
+
+    return _generate_certs(path, days, key_size, separate_key)
